#!python
# -*- coding:utf-8 -*-
import os

"""
Author:Noboru Yamamoto, KEK, Japan (c) 2009-2013

contact info: http://gofer.kek.jp/
or https://plus.google.com/i/xW1BWwWsj3s:2rbmfOGOM4c

Thanks to:
   Dr. Shuei Yamada(KEK, Japan) for improved vxi11scan.py

Revision Info:
$Author: noboru $
$Date: 2020/02/07 09:55:59 $
$Header: /Users/noboru/src/python/VXI11/PyVXI11-Current/cVXI11_revision.py,v 43487ff44ea6 2020/02/07 09:55:59 noboru $
$Id: cVXI11_revision.py,v 43487ff44ea6 2020/02/07 09:55:59 noboru $
$RCSfile: setup.py,v $
$Revision: 43487ff44ea6 $
$Source: /Users/noboru/src/python/VXI11/PyVXI11-Current/cVXI11_revision.py,v $
"""

# macros managedd by mercurial keyword extension
HGTag="$HGTag: 1.14.12-43487ff44ea6 $"
HGdate="$HGdate: Fri, 07 Feb 2020 18:55:59 +0900 $"
HGTagShort="$HGTagShort: 1.14.12 $"
HGlastlog="$lastlog: revision update $"

CVSAuthor="$Author: noboru $"
CVSDate="$Date: 2020/02/07 09:55:59 $"
CVSRev="$Revision: 43487ff44ea6 $"
CVSSource="$Header: /Users/noboru/src/python/VXI11/PyVXI11-Current/cVXI11_revision.py,v 43487ff44ea6 2020/02/07 09:55:59 noboru $"
CVSFile="$Source: /Users/noboru/src/python/VXI11/PyVXI11-Current/cVXI11_revision.py,v $"
CVSId="$Id: cVXI11_revision.py,v 43487ff44ea6 2020/02/07 09:55:59 noboru $"
#
#

rev=HGTag[HGTag.index(":")+1:HGTag.index("-")].strip()




cdef int HiSLIPPort=4880        # not in /etc/services
cdef int SCPIRawSocketPort=5025 # both udp/tcp
cdef int SCPITelnetPort=5024    # both udp/tcp

cdef enum HiSLIPMessageType:
         Initialize=0
         InitializeResPonce=1
         FatalError=2
         Error=3
         AsynLock=4
         AsynLockResponse=5,
         Data=6
         DataEnd=7
         DeviceClearComplete=8
         DeviceCLearAcknowledge=9
         AsyncRemoteLocalContro=10 
         AsyncRemoteLocalResponcse=11
         Trigger=12 
         Interrupted=13
         AsyncInterrupted=14 
         AsyncMaximumMessageSize=15 
         AsyncMaximumMessageSizeResponse=16
         AsyncInitilalize=17
         AsyncIntializeResponse=18
         AsyncDeviceClear=19
         AsyncServiceRequest=20
         AsynStatusQuery=21
         AsyncStatusResponse=22
         AsyncDeviceClearAcknowledge=23
         AsynLockInfo=24 
         AsynLockInfoResponse=25
         # VendorSpecific 128-255 inclusive

cdef enum FatalErrorCodes: # Defined Fatal Error codes. Table-7
        UndefinedError=0
        PoorlyFormedMessage=1
        UnEstablishedConnection=2
        InvalidInitializationSequence=3
        ServerRefued=4
        # 5-127 : reserved
        FirstDeviceDefinedError=128
        # 128-255 : Device Defined Error

cdef enum ErrorCode:  # defined Error codes(non-fatal). Table-9
        UndefinedError=0
        UnrecognizedMessageType=1
        UnrecognizedControlCode=2
        UnrecognizedVendorDefinedMessage=3
        MessageTooLarge=4
        # 5-127 : Reserved
        FirstDviceDefinedError=128
        #128-255:Device Defined Error

cdef enum  LockControlCode:
        release=0
        request=1

cdef enum LockResponseControlCode:
        fail=0
        success=1
        successSharedLock=2
        error=3

cdef RemoteLocalControlCode:
        disableRemote=0
        enableRemote=1
        disableAndGTL=2
        enableAndGotoRemote=3
        enableAndLockoutLocal=4
        enableAndGTRLLO=5
        justGTL=6





cimport PyHiSLIP

import struct 

ctypedef class MessageHeader:
    cdef short prologue #"HS"
    cdef unsigned char messageType
    cdef unsinged char controlCode
    cdef unsinged int messageParameter
    cdef unsinged long payloadLength
    cdef char data[]
    cdef char raw

    def unpack(self,data):
        self.prologue=data[:2] # ASCII "HS"
        self.messageType=data[2] # Message Type 
        self.controlCode=data[3] # Control Code
        self.messageParameter=data[4:8] # Message Parameter
        self.payloadLength=long(data[8:16]) # PayloadLength (8byte int:
        self.data=data[16:] # len(self.data) should be self.payloadLength

    def pack(self):
        self.raw=struct.pack(
            "2cccil",
            self.prologue,
            self.messageType,
            self.controlCode,
            self.messageParameter,
            self.payloadLength)
        self.raw +=self.data # extend binary payload

    @classmethod
    def build_packet(cls, mtype, cc, mparm, payload):
        self.raw=struct.pack(
            "2cccil",
            "HS",
            mtype,
            cc,
            mparm,
            len(payload))
        self.raw +=pyload
        retrun self.raw

    @classmethod
    def unpack_packet(raw):
        obj=cls().unpack(raw)
        return obj
    
import socket

cdef HiSLIPDevice:
     def __init__(self,server, port=HiSLIPPort):
         self.syncport=socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.ssyncport=socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.syncport.connect((server, port))
         self.syncport.send(self.buidmessage(HiSLIPMessageType.Initialize, 0,))


     def Open(self):
         pass

     def Write(self):
         pass

     def Read(self):
         pass

     def ReadSTB(self):
         pass

     def Clear(self):
         pass

     def Lock(self):
         pass

     def AsynLock(self):
         pass

     def Unlock(self):
         pass

     



#!/usr/bin/env python
"""
Author:Noboru Yamamoto, KEK, Japan (c) 2009-2013

contact info: http://gofer.kek.jp/
or https://plus.google.com/i/xW1BWwWsj3s:2rbmfOGOM4c

Thanks to:
   Dr. Shuei Yamada(KEK, Japan) for improved vxi11scan.py

Revision Info:
$Author: noboru $
$Date: 2020/02/27 01:41:53 $ (UTC)
$HGdate: Thu, 27 Feb 2020 10:41:53 +0900 $
$Header: /Users/noboru/src/python/VXI11/PyVXI11-Current/setup.py,v 216ca0159dbf 2020/02/27 01:41:53 noboru $
$Id: setup.py,v 216ca0159dbf 2020/02/27 01:41:53 noboru $
$RCSfile: setup.py,v $
$Revision: 216ca0159dbf $
$Source: /Users/noboru/src/python/VXI11/PyVXI11-Current/setup.py,v $
2020/02/27 : add io_timeout parameters in write.
"""
import os,platform,re,sys

from Cython.Distutils.extension import Extension
from Cython.Distutils import build_ext
from Cython.Build import cythonize

# python2/python3
extra=dict()

# if sys.version_info >= (3,):
#     extra['use_2to3'] = True
    
try:
   from distutils.command.build_py import build_py_2to3 as build_py #for Python3
except ImportError:
   from distutils.command.build_py import build_py     # for Python2

from distutils.core import setup
#from distutils.extension import Extension

# macros managedd by mercurial keyword extension
#
HGTag="$HGTag: 1.14.34-216ca0159dbf $"
HGdate="$HGdate: Thu, 27 Feb 2020 10:41:53 +0900 $" #(rfc822date)
HGTagShort="$HGTagShort: 1.14.34 $"
HGlastlog="$lastlog: exclude rpcl output $"
HGcheckedin="$checked in by: Noboru Yamamoto <noboru.yamamoto@kek.jp> $"
#

#release = os.popen("hg log -r tip --template '{latesttag}.{latesttagdistance}-{node|short}'").read()
release=HGTag
rev=HGTag[HGTag.index(":")+1:HGTag.index("-")].strip()
#

sysname=platform.system()

if re.match("Darwin.*",sysname):
    RPCLIB=["rpcsvc"]
elif re.match("CYGWIN.*",sysname):
    RPCLIB=["rpc"]
else:
    RPCLIB=None

try:
    os.stat("./VXI11.h")
    os.stat("./VXI11_svc.c")
    os.stat("./VXI11_clnt.c")
    os.stat("./VXI11_xdr.c")
except OSError:
    os.system("rpcgen -C -h VXI11.rpcl -o VXI11.h")
    os.system("rpcgen -C -m -L VXI11.rpcl -o VXI11_svc.c")
    os.system("rpcgen -C -l VXI11.rpcl -o VXI11_clnt.c")
    os.system("rpcgen -C -c VXI11.rpcl -o VXI11_xdr.c")
    # use of "-N" option should be considered 2013.11.5 NY

ext_modules=[]

# cVXI11-2.pyx and cVXI11-3.pyx are hard links to cVXI11.pyx
cVXI11_source_PY2="cVXI11_2.pyx"
cVXI11_source_PY3="cVXI11_3.pyx"

if sys.version_info >= (3,):
    cVXI11_source=cVXI11_source_PY3
else:
    cVXI11_source=cVXI11_source_PY2
    
if not os.path.exists(cVXI11_source):
        os.link("cVXI11.pyx", cVXI11_source)

ext_modules.append(Extension("cVXI11", 
                             [ cVXI11_source, # Cython source. i.e. .pyx
                               "VXI11_clnt.c", "VXI11_xdr.c", #"VXI11_svc.c", 
                               "createAbtChannel.c",
                               "cPMAP.cpp",
                             ]
                             ,libraries=RPCLIB
                             ,depends=["cVXI11.pxd"] # Cython interface file
                             ,language="c++"
                             ,cython_cplus=True
                             ,undef_macros=["CFLAGS"]
                             ,extra_compile_args=["-I/usr/include/tirpc"],
))


## if you  like to compare cython version with swig-version, uncomment the 
## following lines. You must have swig in your path.
# ext_modules.append(Extension("_VXI11",["VXI11.i","VXI11_clnt.c","VXI11_xdr.c"]
#                     ,swig_opts=["-O","-nortti"]
#                     ,libraries=RPCLIB
#                     ))

ext_modules=cythonize(ext_modules,
                      compiler_directives={"language_level":"2"}
)

setup(name="PyVXI11",
      version=rev,
      author="Noboru Yamamoto, KEK, JAPAN",
      author_email = "Noboru.YAMAMOTO@kek.jp",
      description='A Cython based Python module to control devices over VXI11 protocol.',
      url="http://www-cont.j-parc.jp/",
      classifiers=['Programming Language :: Python',
                   'Programming Language :: Cython',
                   'Topic :: Scientific/Engineering :: Interface Engine/Protocol Translator',
                   ],
      ext_modules=ext_modules,
      cmdclass = {'build_ext': build_ext,
                  # 'build_py':build_py  # for 2to3 
      },
      py_modules=[
          "RebootLanGbib","AgilentDSO",
          "TekOSC","TekDPO","LeCroy",
          "vxi11Exceptions","cVXI11_revision",
          #"vxi11scan","VXI11","vxi11Device",
      ],
      **extra
)
